| tw_check_qid | R Documentation |
Mostly used internally by other functions.
tw_check_qid(id, logical_vector = FALSE, non_id_as_NA = FALSE)
id |
A character vector of one or more Wikidata id. |
logical_vector |
Logical, defaults to |
non_id_as_NA |
Logical, defaults to |
A character vector with only strings appearing to be Wikidata identifiers; possibly shorter than input.
tw_check_qid(id = c("Q180099", "q228822", "Not an id", "00180099", NA, "Q5"))
tw_check_qid(
id = c("Q180099", "q228822", "Not an id", "00180099", NA, "Q5"),
logical_vector = TRUE
)
tw_check_qid(
id = c("Q180099", "q228822", "Not an id", "00180099", NA, "Q5"),
non_id_as_NA = TRUE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.