| tw_check_search | R Documentation |
Mostly used as a convenience function inside other functions to have consistent inputs.
tw_check_search(
search,
type = "item",
language = tidywikidatar::tw_get_language(),
response_language = tidywikidatar::tw_get_language(),
limit = 10,
include_search = FALSE,
wait = 0,
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE
)
search |
A string to be searched in Wikidata |
type |
Defaults to "item". Either "item" or "property". |
language |
Language to be used for the search. Can be set once per
session with |
response_language |
Language to be used for the returned labels and
descriptions. Corresponds to the |
limit |
Maximum numbers of responses to be given. |
include_search |
Logical, defaults to |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
cache |
Defaults to |
overwrite_cache |
Defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
A data frame with three columns, id, label, and description,
filtered by the above criteria. Four columns if include_search is set to
TRUE.
# The following two lines should give the same result.
tw_check_search("Sylvia Pankhurst")
tw_check_search(tw_search("Sylvia Pankhurst"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.