View source: R/tw_get_cached_item.R
| tw_get_cached_item | R Documentation |
Retrieve cached item
tw_get_cached_item(
id,
language = tidywikidatar::tw_get_language(),
cache = NULL,
cache_connection = NULL,
disconnect_db = TRUE
)
id |
A character vector, must start with Q, e.g. "Q180099" for the
anthropologist Margaret Mead. Can also be a data frame of one row,
typically generated with |
language |
Defaults to language set with |
cache |
Defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
If data present in cache, returns a data frame with cached data.
tw_set_cache_folder(path = tempdir())
tw_enable_cache()
tw_create_cache_folder(ask = FALSE)
df_from_api <- tw_get(id = "Q180099", language = "en")
df_from_cache <- tw_get_cached_item(
id = "Q180099",
language = "en"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.