Retrieve cached search
Usage
tw_get_cached_search(
search,
type = "item",
language = tidywikidatar::tw_get_language(),
response_language = tidywikidatar::tw_get_language(),
cache = NULL,
include_search = FALSE,
cache_connection = NULL,
disconnect_db = TRUE
)Arguments
- search
A string to be searched in Wikidata
- type
Defaults to "item". Either "item" or "property".
- language
Language to be used for the search. Can be set once per session with
tw_set_language(). If not set, defaults to "en". For a full list, see the dedicated Wikimedia page.- response_language
Language to be used for the returned labels and descriptions. Corresponds to the
uselangparameter of the MediaWiki API, as described in the official documentation. Can be set once per session withtw_set_language(). If not set, defaults to "en". For a full list, see all available language codes.- cache
Defaults to
NULL. If given, it should be given eitherTRUEorFALSE.Typically set withtw_enable_cache()ortw_disable_cache().- include_search
Logical, defaults to
FALSE. IfTRUE, the search is returned as an additional column.- cache_connection
Defaults to
NULL. IfNULL, and caching is enabled,tidywikidatarwill use a local sqlite database. A custom connection to other databases can be given (see vignettecachingfor details).- disconnect_db
Defaults to
TRUE. IfFALSE, leaves the connection to cache open.
Examples
if (FALSE) { # \dontrun{
tw_set_cache_folder(path = tempdir())
tw_enable_cache()
tw_create_cache_folder(ask = FALSE)
search_from_api <- tw_search("Sylvia Pankhurst")
search_from_api
df_from_cache <- tw_get_cached_search("Sylvia Pankhurst")
df_from_cache
} # }