Please consult the relevant documentation for reusing content outside Wikimedia.
tw_get_image_metadata(
id,
image_filename = NULL,
only_first = TRUE,
language = tidywikidatar::tw_get_language(),
id_df = NULL,
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
attempts = 10,
wait = 1,
retry = 10,
user_agent = tidywikidatar::tw_get_user_agent()
)A character vector, corresponding to reference to the image in the requested format.
A character vector of length 1, must start with Q, e.g. "Q254" for Wolfgang Amadeus Mozart.
Defaults to NULL. If NULL, image_filename is
obtained from the Wikidata id. If given, must be of the same length as id.
Defaults to TRUE. If TRUE, returns only the first image
associated with a given Wikidata id. If FALSE, returns all images
available.
Defaults to language set with tw_set_language(); if not
set, "en". Use "all_available" to keep all languages. For available
language values, see
the
dedicated Wikimedia page.
Default to NULL. If given, it should be a dataframe typically
generated with tw_get(), and is used instead of calling Wikidata or
using SQLite cache. Ignored when id is of length more than one.
Defaults to NULL. If given, it should be given either TRUE
or FALSE. Typically set with tw_enable_cache() or tw_disable_cache().
Logical, defaults to FALSE. If TRUE, it overwrites
the table in the local sqlite database. Useful if the original Wikidata
object has been updated.
Defaults to NULL. If NULL, and caching is
enabled, tidywikidatar will use a local sqlite database. A custom
connection to other databases can be given (see vignette caching for
details).
Defaults to TRUE. If FALSE, leaves the connection to
cache open.
Defaults to 10. Number of times it re-attempts to reach the API before failing.
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries.
Defaults to 10. Maximum number of times to retry if the API
throws an error, such as "too many requests". Each time, it will wait as
much time as requested by the API. Notice that this can be a long time,
e.g. 30 minutes. Set to FALSE if you prefer the API to throw an error
immediately. Consider adjusting the wait parameter, or customising the
user_agent if relevant.
Defaults to NULL. If not given, implicitly defaults to
current package name (tidywikidatar) and version.
if (FALSE) {
tw_get_image_metadata("Q180099")
}
Run the code above in your browser using DataLab