View source: R/tw_get_property.R
| tw_get_p1 | R Documentation |
This function wraps tw_get_p(), but always sets only_first and
preferred to TRUE in order to give back always a character vector.
tw_get_p1(
id,
p,
latest_start_time = FALSE,
language = tidywikidatar::tw_get_language(),
id_df = NULL,
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
wait = 0
)
id |
A character vector, must start with Q, e.g. "Q180099" for the
anthropologist Margaret Mead. Can also be a data frame of one row,
typically generated with |
p |
A character vector, a property. Must always start with the capital letter "P", e.g. "P31" for "instance of". |
latest_start_time |
Logical, defaults to |
language |
Defaults to language set with |
id_df |
Default to |
cache |
Defaults to |
overwrite_cache |
Logical, defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
A character vector of the same length as the input.
tw_get_p1(id = "Q180099", "P26")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.