View source: R/tw_get_p_wide.R
| tw_get_p_wide | R Documentation |
Efficiently get a wide table with various properties of a given set of Wikidata identifiers
tw_get_p_wide(
id,
p,
label = FALSE,
property_label_as_column_name = FALSE,
both_id_and_label = FALSE,
only_first = FALSE,
preferred = FALSE,
unlist = FALSE,
collapse = ";",
language = tidywikidatar::tw_get_language(),
id_df = NULL,
id_df_label = NULL,
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
wait = 0
)
id |
A character vector, must start with Q, e.g. "Q180099" for the
anthropologist Margaret Mead. Can also be a data frame of one row,
typically generated with |
p |
A character vector, a property. Must always start with the capital letter "P", e.g. "P31" for "instance of". |
label |
Logical, defaults to |
property_label_as_column_name |
Logical, defaults to |
both_id_and_label |
Logical, defaults to |
only_first |
Logical, defaults to |
preferred |
Logical, defaults to |
unlist |
Logical, defaults to |
collapse |
Defaults to ";". Character used to separate results when
|
language |
Defaults to language set with |
id_df |
Default to |
id_df_label |
Defaults to NULL. If given, it should be a dataframe
typically generated with |
cache |
Defaults to |
overwrite_cache |
Logical, defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
A data frame, with a column for each given property.
if (interactive()) {
tw_get_p_wide(
id = c("Q180099", "Q228822", "Q191095"),
p = c("P27", "P19", "P20"),
label = TRUE,
only_first = TRUE
)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.