View source: R/tw_get_property_description.R
| tw_get_property_description_single | R Documentation |
Get description of a Wikidata property in a given language
tw_get_property_description_single(
property,
language = tidywikidatar::tw_get_language(),
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
wait = 0
)
property |
A character vector of length 1, must start with P, e.g. "P31". |
language |
Defaults to language set with |
cache |
Defaults to |
overwrite_cache |
Logical, defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
A character vector of length 1, with the Wikidata description in the requested language.
tidywikidatar:::tw_get_property_description_single(property = "P31")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.