Get URL to a Wikipedia article corresponding to a Wikidata Q identifier in given language
Source:R/tw_get_others.R
tw_get_wikipedia.RdGet URL to a Wikipedia article corresponding to a Wikidata Q identifier in given language
Usage
tw_get_wikipedia(
id,
full_link = TRUE,
language = tidywikidatar::tw_get_language(),
id_df = NULL,
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
wait = 0,
retry = 10,
user_agent = tidywikidatar::tw_get_user_agent()
)Arguments
- id
A character vector of length 1, must start with Q, e.g. "Q254" for Wolfgang Amadeus Mozart.
- full_link
Logical, defaults to
TRUE. IfFALSE, returns only the part of the url that corresponds to the title.- language
Defaults to language set with
tw_set_language(); if not set, "en". Use "all_available" to keep all languages. For available language values, see the dedicated Wikimedia page.- id_df
Default to NULL. If given, it should be a dataframe typically generated with
tw_get(), and is used instead of calling Wikidata or using SQLite cache. Ignored whenidis of length more than one.- cache
Defaults to
NULL. If given, it should be given eitherTRUEorFALSE. Typically set withtw_enable_cache()ortw_disable_cache().- overwrite_cache
Logical, defaults to
FALSE. IfTRUE, it overwrites the table in the local sqlite database. Useful if the original Wikidata object has been updated.- cache_connection
Defaults to
NULL. IfNULL, and caching is enabled,tidywikidatarwill use a local sqlite database. A custom connection to other databases can be given (see vignettecachingfor details).- disconnect_db
Defaults to
TRUE. IfFALSE, leaves the connection to cache open.- wait
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries.
- retry
Defaults to 10. Maximum number of times to retry if the API throws an error, such as "too many requests". Each time, it will wait as much time as requested by the API. Notice that this can be a long time, e.g. 30 minutes. Set to
FALSEif you prefer the API to throw an error immediately. Consider adjusting thewaitparameter, or customising theuser_agentif relevant.- user_agent
Defaults to
NULL. If not given, implicitly defaults to current package name (tidywikidatar) and version.