View source: R/tw_get_wikipedia_category_members.R
| tw_get_wikipedia_category_members | R Documentation |
Get all Wikidata Q identifiers of all Wikipedia pages (or files, or subcategories) that are members of the given category,
tw_get_wikipedia_category_members(
url = NULL,
category = NULL,
type = "page",
language = tidywikidatar::tw_get_language(),
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
wait = 1,
attempts = 10
)
url |
Full URL to a Wikipedia category page. If given, title and language can be left empty. |
category |
Title of a Wikipedia category page or final parts of its url. Must include "Category:", or equivalent in other languages. If given, url can be left empty, but language must be provided. |
type |
Defaults to "page", defines which kind of members of a category
are returned. Valid values include "page", "file", and "subcat" (for
sub-category). Corresponds to |
language |
Defaults to language set with |
cache |
Defaults to |
overwrite_cache |
Logical, defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
attempts |
Defaults to 10. Number of times it re-attempts to reach the API before failing. |
A data frame (a tibble) with eight columns: source_title_url,
source_wikipedia_title, source_qid, wikipedia_title, wikipedia_id,
qid, description, and language.
if (interactive()) {
sub_categories <- tw_get_wikipedia_category_members(
category = "Category:American women anthropologists",
type = "subcat"
)
sub_categories
tw_get_wikipedia_category_members(
category = sub_categories$wikipedia_title,
type = "page"
)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.