View source: R/tw_get_wikipedia_page_links.R
| tw_get_wikipedia_page_links_single | R Documentation |
Get all Wikidata Q identifiers of all Wikipedia pages that appear in a given page
tw_get_wikipedia_page_links_single(
url = NULL,
title = NULL,
language = tidywikidatar::tw_get_language(),
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
wait = 1,
attempts = 10,
wikipedia_page_qid_df = NULL
)
url |
Full url to a Wikipedia page. If given, title and language can be left empty. |
title |
Title of a Wikipedia page or final parts of its url. If given, url can be left empty, but language must be provided. |
language |
Two-letter language code used to define the Wikipedia version
to use. Defaults to language set with |
cache |
Defaults to |
overwrite_cache |
Logical, defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
attempts |
Defaults to 10. Number of times it re-attempts to reach the API before failing. |
wikipedia_page_qid_df |
Defaults to |
A data frame (a tibble) with four columns: wikipedia_title,
wikipedia_id, wikidata_id, wikidata_description.
if (interactive()) {
tw_get_wikipedia_page_links_single(title = "Margaret Mead", language = "en")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.