View source: R/tw_get_wikipedia_page_qid.R
| tw_get_wikipedia_page_qid | R Documentation |
Gets the Wikidata Q identifier of one or more Wikipedia pages
tw_get_wikipedia_page_qid(
url = NULL,
title = NULL,
language = tidywikidatar::tw_get_language(),
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
wait = 1,
attempts = 10
)
url |
A character vector with the full URL to one or more Wikipedia pages. If given, title and language can be left empty. |
title |
Title of a Wikipedia page or final parts of its url. If given, url can be left empty, but language must be provided. |
language |
Defaults to language set with |
cache |
Defaults to |
overwrite_cache |
Logical, defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
attempts |
Defaults to 10. Number of times it re-attempts to reach the API before failing. |
A a data frame with six columns, including qid with Wikidata
identifiers, and a logical disambiguation to flag when disambiguation
pages are returned.
if (interactive()) {
tw_get_wikipedia_page_qid(title = "Margaret Mead", language = "en")
# check when Wikipedia returns disambiguation page
tw_get_wikipedia_page_qid(title = c("Rome", "London", "New York", "Vienna"))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.