| tw_label | R Documentation |
Gets labels for all columns with names such as "id" and "property".
tw_label(
df,
value = TRUE,
language = tidywikidatar::tw_get_language(),
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
wait = 0
)
df |
A data frame, typically generated with other |
value |
Logical, defaults to |
language |
Defaults to language set with |
cache |
Defaults to |
overwrite_cache |
Logical, defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
A data frame, with the same shape as the input data frame, but with labels instead of identifiers.
if (interactive()) {
tw_get_qualifiers(id = "Q180099", p = "P26", language = "en") %>%
head(2) %>%
tw_label()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.