Learn R Programming

tidywikidatar (version 0.6.1)

tw_qid_meps: The Wikidata Q identifier of all members of the European Parliament since its establishment

Description

A dataset with all the Wikidata items that have "Q27169" (member of the European Parliament) for the property "P39" (position held).

Usage

tw_qid_meps

Arguments

Format

A data frame with 4581 rows and 1 column:

id

Q identifiers