View source: R/tw_get_wikipedia_category_members.R
| tw_reset_wikipedia_category_members_cache | R Documentation |
Removes from cache the table where data typically gathered with
tw_get_wikipedia_category_members() are stored.
tw_reset_wikipedia_category_members_cache(
language = tidywikidatar::tw_get_language(),
type = "page",
cache = NULL,
cache_connection = NULL,
disconnect_db = TRUE,
ask = TRUE
)
language |
Two-letter language code used to define the Wikipedia version
to use. Defaults to language set with |
type |
Defaults to "page", defines which kind of members of a category
are returned. Valid values include "page", "file", and "subcat" (for
sub-category). Corresponds to |
cache |
Defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
ask |
Logical, defaults to TRUE. If FALSE, and cache folder does not exist, it just creates it without asking (useful for non-interactive sessions). |
Nothing, used for its side effects.
if (interactive()) {
tw_reset_wikipedia_category_members_cache()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.