tw_test_items: A list mostly used for testing with some Wikidata items in...

tw_test_itemsR Documentation

A list mostly used for testing with some Wikidata items in the format resulting from tw_get_item()

Description

A list mostly used for testing with some Wikidata items in the format resulting from tw_get_item()

Usage

tw_test_items

Format

A list, an object such as the one resulting from tw_get_item()


tidywikidatar documentation built on Feb. 10, 2026, 1:07 a.m.