Mostly to be used internally by tidywikidatar, use with caution to keep
caching consistent.
Usage
tw_write_qualifiers_to_cache(
qualifiers_df,
language = tidywikidatar::tw_get_language(),
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE
)Arguments
- qualifiers_df
A data frame typically generated with
tw_get_qualifiers().- language
Defaults to language set with
tw_set_language(); if not set, "en". Use "all_available" to keep all languages. For available language values, see the dedicated Wikimedia page.- cache
Defaults to
NULL. If given, it should be given eitherTRUEorFALSE. Typically set withtw_enable_cache()ortw_disable_cache().- overwrite_cache
Logical, defaults to
FALSE. IfTRUE, it overwrites the table in the local sqlite database. Useful if the original Wikidata object has been updated.- cache_connection
Defaults to
NULL. IfNULL, and caching is enabled,tidywikidatarwill use a local sqlite database. A custom connection to other databases can be given (see vignettecachingfor details).- disconnect_db
Defaults to
TRUE. IfFALSE, leaves the connection to cache open.
Value
Silently returns the same data frame provided as input. Mostly used internally for its side effects.
Examples
if (interactive()) {
q_df <- tw_get_qualifiers(
id = "Q180099",
p = "P26",
language = "en",
cache = FALSE
)
tw_write_qualifiers_to_cache(
qualifiers_df = q_df,
language = "en",
cache = TRUE
)
}