View source: R/tw_get_wikipedia_page_links.R
| tw_write_wikipedia_page_links_to_cache | R Documentation |
Mostly used internally by tidywikidatar, use with caution to keep caching
consistent.
tw_write_wikipedia_page_links_to_cache(
df,
language = tidywikidatar::tw_get_language(),
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE
)
df |
A data frame typically generated with
|
language |
Two-letter language code used to define the Wikipedia version
to use. Defaults to language set with |
cache |
Defaults to |
overwrite_cache |
Logical, defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
Silently returns the same data frame provided as input. Mostly used internally for its side effects.
if (interactive()) {
df <- tw_get_wikipedia_page_links(
title = "Margaret Mead",
language = "en",
cache = FALSE
)
tw_write_wikipedia_page_links_to_cache(
df = df,
language = "en"
)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.