View source: R/tw_get_cached_item.R
| tw_check_cached_items | R Documentation |
Check if given items are present in cache
tw_check_cached_items(
id,
language = tidywikidatar::tw_get_language(),
cache_connection = NULL,
disconnect_db = TRUE
)
id |
A character vector, must start with Q, e.g. "Q180099" for the
anthropologist Margaret Mead. Can also be a data frame of one row,
typically generated with |
language |
Defaults to language set with |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
A character vector with IDs of items present in cache. If no item
found in cache, returns NULL.
if (interactive()) {
tw_set_cache_folder(path = tempdir())
tw_enable_cache()
tw_create_cache_folder(ask = FALSE)
# add three items to local cache
invisible(tw_get(id = "Q180099", language = "en"))
invisible(tw_get(id = "Q228822", language = "en"))
invisible(tw_get(id = "Q184992", language = "en"))
# check if these other items are in cache
items_in_cache <- tw_check_cached_items(
id = c(
"Q180099",
"Q228822",
"Q76857"
),
language = "en"
)
# it should return only the two items from the current list of id
# but not other item already in cache
items_in_cache
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.