| tw_check_pid | R Documentation |
Mostly used internally by other functions.
tw_check_pid(property, logical_vector = FALSE, non_pid_as_NA = FALSE)
property |
A character vector of one or more Wikidata property identifiers. |
logical_vector |
Logical, defaults to |
non_pid_as_NA |
Logical, defaults to |
A character vector with only strings appearing to be Wikidata identifiers; possibly shorter than input.
tw_check_pid(property = c("P19", "p20", "Not an property id", "20", NA, "Q5", ""))
tw_check_pid(
property = c("P19", "p20", "Not an property id", "20", NA, "Q5", ""),
logical_vector = TRUE
)
tw_check_pid(
property = c("P19", "p20", "Not an property id", "20", NA, "Q5", ""),
non_pid_as_NA = TRUE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.