Mostly used as a convenience function inside other functions to have consistent inputs.
tw_check_search(
search,
type = "item",
language = tidywikidatar::tw_get_language(),
response_language = tidywikidatar::tw_get_language(),
limit = 10,
include_search = FALSE,
wait = 0,
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE
)A data frame with three columns, id, label, and description,
filtered by the above criteria. Four columns if include_search is set to
TRUE.
A string to be searched in Wikidata
Defaults to "item". Either "item" or "property".
Language to be used for the search. Can be set once per
session with tw_set_language(). If not set, defaults to "en". For a full
list, see
the
dedicated Wikimedia page.
Language to be used for the returned labels and
descriptions. Corresponds to the uselang parameter of the MediaWiki API,
as described
in
the official documentation. Can be set once per session with
tw_set_language(). If not set, defaults to "en". For a full list, see
all
available language codes.
Maximum numbers of responses to be given.
Logical, defaults to FALSE. If TRUE, the search is
returned as an additional column.
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries.
Defaults to NULL. If given, it should be given either TRUE
or FALSE. Typically set with tw_enable_cache() or tw_disable_cache().
Defaults to FALSE. If TRUE, overwrites cache.
Defaults to NULL. If NULL, and caching is
enabled, tidywikidatar will use a local sqlite database. A custom
connection to other databases can be given (see vignette caching for
details).
Defaults to TRUE. If FALSE, leaves the connection to
cache open.
# The following two lines should give the same result.
tw_check_search("Sylvia Pankhurst")
tw_check_search(tw_search("Sylvia Pankhurst"))
Run the code above in your browser using DataLab