Learn R Programming

tidywikidatar (version 0.6.2)

tw_extract_qualifier: Extract qualifiers from a list created with tw_get_item()

Description

This function is mostly used internally and for testing.

Usage

tw_extract_qualifier(
  id,
  p,
  w = NULL,
  retry = 10,
  user_agent = tidywikidatar::tw_get_user_agent()
)

Value

A data frame (a tibble) with eight columns: id for the input id, property, qualifier_id, qualifier_property, qualifier_value, rank, qualifier_value_type, and set (to distinguish sets of data when a property is present more than once)

Arguments

id

A character vector, must start with Q, e.g. "Q180099" for the anthropologist Margaret Mead. Can also be a data frame of one row, typically generated with tw_search() or a combination of tw_search() and tw_filter_first().

p

A character vector, a property. Must always start with the capital letter "P", e.g. "P31" for "instance of".

w

A list, typically created with tw_get_item()

retry

Defaults to 10. Maximum number of times to retry if the API throws an error, such as "too many requests". Each time, it will wait as much time as requested by the API. Notice that this can be a long time, e.g. 30 minutes. Set to FALSE if you prefer the API to throw an error immediately. Consider adjusting the wait parameter, or customising the user_agent if relevant.

user_agent

Defaults to NULL. If not given, implicitly defaults to current package name (tidywikidatar) and version.

Examples

Run this code
# w <- tw_get_item(id = "Q180099")

tw_extract_qualifier(id = "Q180099", p = "P26", w = list(tw_test_items[["Q180099"]]))

Run the code above in your browser using DataLab