Learn R Programming

tidywikidatar (version 0.6.1)

tw_extract_qualifier: Extract qualifiers from a list created with tw_get_item()

Description

This function is mostly used internally and for testing.

Usage

tw_extract_qualifier(id, p, w = NULL)

Value

A data frame (a tibble) with eight columns: id for the input id, property, qualifier_id, qualifier_property, qualifier_value, rank, qualifier_value_type, and set (to distinguish sets of data when a property is present more than once)

Arguments

id

A character vector of length 1, must start with Q, e.g. "Q254" for Wolfgang Amadeus Mozart.

p

A character vector of length 1, a property. Must always start with the capital letter "P", e.g. "P31" for "instance of".

w

A list, typically created with tw_get_item()

Examples

Run this code
# w <- tw_get_item(id = "Q180099")

tw_extract_qualifier(id = "Q180099", p = "P26", w = list(tw_test_items[["Q180099"]]))

Run the code above in your browser using DataLab