| tw_extract_single | R Documentation |
This function is mostly used internally and for testing.
tw_extract_single(w, language = tidywikidatar::tw_get_language())
w |
A list, typically retrieved with |
language |
Defaults to language set with |
A data frame (a tibble) with four columns, such as the one created by
tw_get().
#' Retrieving from tests, but normally:
# w <- tw_get_item(id = "Q180099")
tidywikidatar:::tw_extract_single(w = list(tw_test_items[["Q180099"]]))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.