tw_extract_single: Extract item data from a list object retrieved from the Wikidata API
Description
This function is mostly used internally and for testing.
Usage
tw_extract_single(w, language = tidywikidatar::tw_get_language())
Value
A data frame (a tibble) with four columns, such as the one created by
tw_get().
Arguments
w
A list, typically retrieved with tw_get_item()
language
Defaults to language set with tw_set_language(); if not
set, "en". Use "all_available" to keep all languages. For available
language values, see
the
dedicated Wikimedia page.