tw_extract_single: Extract item data from an object of class Wikidata created with WikidataR
Description
This function is mostly used internally and for testing.
Usage
tw_extract_single(w, language = tidywikidatar::tw_get_language())
Value
A data frame (a tibble) with four columns, such as the one created by tw_get.
Arguments
w
An object of class Wikidata created with WikidataR, typically created with WikidataR::get_item(id = id)
language
Defaults to language set with tw_set_language(); if not set, "en". Use "all_available" to keep all languages. For available language values, see https://www.wikidata.org/wiki/Help:Wikimedia_language_codes/lists/all