| tw_filter_people | R Documentation |
A wrapper of tw_filter() that defaults to keep only "instance of" (P31)
"human being" (Q5).
tw_filter_people(
search,
language = tidywikidatar::tw_get_language(),
response_language = tidywikidatar::tw_get_language(),
limit = 10,
include_search = FALSE,
stop_at_first = TRUE,
wait = 0,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE
)
search |
A data frame generated by |
language |
Language to be used for the search. Can be set once per
session with |
response_language |
Language to be used for the returned labels and
descriptions. Corresponds to the |
limit |
Maximum numbers of responses to be given. |
include_search |
Logical, defaults to |
stop_at_first |
Logical, defaults to TRUE. If TRUE, returns only the first match from the search that satisfies the criteria. |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
overwrite_cache |
Defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
A data frame with three columns, id, label, and description;
all rows refer to a human being.
tw_search("Ruth Benedict")
tw_search("Ruth Benedict") %>%
tw_filter_people()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.