| tw_get | R Documentation |
Return (most) information from a Wikidata item in a tidy format
tw_get(
id,
language = tidywikidatar::tw_get_language(),
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
wait = 0,
id_l = NULL,
user_agent = tidywikidatar::tw_get_user_agent()
)
id |
A character vector, must start with Q, e.g. "Q180099" for the
anthropologist Margaret Mead. Can also be a data frame of one row,
typically generated with |
language |
Defaults to language set with |
cache |
Defaults to |
overwrite_cache |
Logical, defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
id_l |
Defaults to |
user_agent |
Defaults to |
A data.frame (a tibble) with three columns (id, property, and
value).
if (interactive()) {
tw_get(
id = c("Q180099", "Q228822"),
language = "en"
)
}
## using `tw_test_items` in examples in order to show output without calling
## on Wikidata servers
tw_get(
id = c("Q180099", "Q228822"),
language = "en",
id_l = tw_test_items
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.