- id
A character vector, must start with Q, e.g. "Q180099" for the
anthropologist Margaret Mead. Can also be a data frame of one row,
typically generated with tw_search() or a combination of tw_search()
and tw_filter_first().
- language
Defaults to language set with tw_set_language(); if not
set, "en". Use "all_available" to keep all languages. For available
language values, see
the
dedicated Wikimedia page.
- cache
Defaults to NULL. If given, it should be given either TRUE
or FALSE. Typically set with tw_enable_cache() or tw_disable_cache().
- overwrite_cache
Logical, defaults to FALSE. If TRUE, it overwrites
the table in the local sqlite database. Useful if the original Wikidata
object has been updated.
- cache_connection
Defaults to NULL. If NULL, and caching is
enabled, tidywikidatar will use a local sqlite database. A custom
connection to other databases can be given (see vignette caching for
details).
- disconnect_db
Defaults to TRUE. If FALSE, leaves the connection to
cache open.
- wait
In seconds, defaults to 0. Time to wait between queries to
Wikidata. If data are cached locally, wait time is not applied. If you are
running many queries systematically you may want to add some waiting time
between queries.
- id_l
Defaults to NULL. If given, must be an object or list such as
the one generated with tw_get_item(). If given, and the requested
id is actually present in id_l, then no query to Wikidata servers is
made.
- user_agent
Defaults to NULL. If not given, implicitly defaults to
current package name (tidywikidatar) and version.