View source: R/tw_get_cached_item.R
| tw_get_cache_table_name | R Documentation |
Gets name of table inside the database
tw_get_cache_table_name(
type = "item",
language = tidywikidatar::tw_get_language(),
response_language = tidywikidatar::tw_get_language()
)
type |
Defaults to "item". Type of cache file to output. Values
typically used by |
language |
Language to be used for the search. Can be set once per
session with |
response_language |
Language to be used for the returned labels and
descriptions. Corresponds to the |
A character vector of length one with the name of the relevant table in the cache file.
# outputs name of table used in the cache database
tw_get_cache_table_name(type = "item", language = "en")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.