Get Wikidata description in given language
tw_get_description(
id,
language = tidywikidatar::tw_get_language(),
id_df = NULL,
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
wait = 0
)A character vector of the same length as the vector of id given, with the Wikidata description in the requested language.
A character vector of length 1, must start with Q, e.g. "Q254" for Wolfgang Amadeus Mozart.
Defaults to language set with tw_set_language(); if not
set, "en". Use "all_available" to keep all languages. For available
language values, see
the
dedicated Wikimedia page.
Default to NULL. If given, it should be a dataframe typically
generated with tw_get(), and is used instead of calling Wikidata or
using SQLite cache. Ignored when id is of length more than one.
Defaults to NULL. If given, it should be given either TRUE
or FALSE. Typically set with tw_enable_cache() or tw_disable_cache().
Logical, defaults to FALSE. If TRUE, it overwrites
the table in the local sqlite database. Useful if the original Wikidata
object has been updated.
Defaults to NULL. If NULL, and caching is
enabled, tidywikidatar will use a local sqlite database. A custom
connection to other databases can be given (see vignette caching for
details).
Defaults to TRUE. If FALSE, leaves the connection to
cache open.
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries.
tw_get_description(
id = c(
"Q180099",
"Q228822"
),
language = "en"
)
Run the code above in your browser using DataLab