| tw_get_image | R Documentation |
Please consult the relevant documentation for reusing content outside Wikimedia.
tw_get_image(
id,
format = "filename",
width = NULL,
language = tidywikidatar::tw_get_language(),
id_df = NULL,
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
wait = 0
)
id |
A character vector of length 1, must start with Q, e.g. "Q254" for Wolfgang Amadeus Mozart. |
format |
A character vector, defaults to |
width |
A numeric value, defaults to |
language |
Defaults to language set with |
id_df |
Default to NULL. If given, it should be a dataframe typically
generated with |
cache |
Defaults to |
overwrite_cache |
Logical, defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
A data frame of two columns, id and image, corresponding to
reference to the image in the requested format.
tw_get_image("Q180099",
format = "filename"
)
if (interactive()) {
tw_get_image("Q180099",
format = "commons"
)
tw_get_image("Q180099",
format = "embed",
width = 300
)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.