| tw_get_item | R Documentation |
Retrieve item from the Wikidata API and returns it as a list
tw_get_item(id, user_agent = tidywikidatar::tw_get_user_agent())
id |
A character vector, must start with Q, e.g. "Q180099" for the
anthropologist Margaret Mead. Can also be a data frame of one row,
typically generated with |
user_agent |
Defaults to |
A list, with as many elements as the unique given id.
## Not run:
item_l <- tw_get_item(id = "Q180099")
tidywikidatar:::tw_extract_single(w = item_l)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.