Learn R Programming

tidywikidatar (version 0.6.1)

tw_get_item: Retrieve item from the Wikidata API and returns it as a list

Description

Retrieve item from the Wikidata API and returns it as a list

Usage

tw_get_item(id, user_agent = tidywikidatar::tw_get_user_agent())

Value

A list, with as many elements as the unique given id.

Arguments

id

A character vector, must start with Q, e.g. "Q180099" for the anthropologist Margaret Mead. Can also be a data frame of one row, typically generated with tw_search() or a combination of tw_search() and tw_filter_first().

user_agent

Defaults to NULL. If not given, implicitly defaults to current package name (tidywikidatar) and version.

Examples

Run this code
if (FALSE) {
  item_l <- tw_get_item(id = "Q180099")

  tidywikidatar:::tw_extract_single(w = item_l)
}

Run the code above in your browser using DataLab