A list, with as many elements as the unique given id.
Arguments
id
A character vector, must start with Q, e.g. "Q180099" for the
anthropologist Margaret Mead. Can also be a data frame of one row,
typically generated with tw_search() or a combination of tw_search()
and tw_filter_first().
user_agent
Defaults to NULL. If not given, implicitly defaults to
current package name (tidywikidatar) and version.