View source: R/tw_get_others.R
| tw_get_label | R Documentation |
Get Wikidata label in given language
tw_get_label(
id,
language = tidywikidatar::tw_get_language(),
id_df = NULL,
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
wait = 0
)
id |
A character vector of length 1, must start with Q, e.g. "Q254" for Wolfgang Amadeus Mozart. |
language |
Defaults to language set with |
id_df |
Default to NULL. If given, it should be a dataframe typically
generated with |
cache |
Defaults to |
overwrite_cache |
Logical, defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
A character vector of the same length as the vector of id given, with the Wikidata label in the requested language.
tw_get_label(
id = c(
"Q180099",
"Q228822"
),
language = "en"
)
# If a label is not available, a NA value is returned
if (interactive()) {
tw_get_label(
id = c(
"Q64733534",
"Q4773904",
"Q220480"
),
language = "sc"
)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.