View source: R/tw_get_property.R
| tw_get_property | R Documentation |
Get Wikidata property of one or more items as a tidy data frame
tw_get_property(
id,
p,
language = tidywikidatar::tw_get_language(),
id_df = NULL,
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
wait = 0
)
id |
A character vector, must start with Q, e.g. "Q180099" for the
anthropologist Margaret Mead. Can also be a data frame of one row,
typically generated with |
p |
A character vector, a property. Must always start with the capital letter "P", e.g. "P31" for "instance of". |
language |
Defaults to language set with |
id_df |
Default to |
cache |
Defaults to |
overwrite_cache |
Logical, defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
A tibble, corresponding to the value for the given property. A tibble of zero rows if no relevant property found.
# Who were the doctoral advisors - P184 - of Margaret Mead - Q180099?
advisors <- tw_get_property(id = "Q180099", p = "P184")
advisors
# tw_get_label(advisors)
# It is also possible to get one property for many id
if (interactive()) {
tw_get_property(
id = c(
"Q180099",
"Q228822"
),
p = "P31"
)
# Or many properties for a single id
tw_get_property(
id = "Q180099",
p = c("P21", "P31")
)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.