- id
A character vector, must start with Q, e.g. "Q180099" for the
anthropologist Margaret Mead. Can also be a data frame of one row,
typically generated with tw_search() or a combination of tw_search()
and tw_filter_first().
- p
A character vector, a property. Must always start with the capital
letter "P", e.g. "P31" for "instance of".
- only_first
Logical, defaults to FALSE. If TRUE, it just keeps the
first relevant property value for each id (or NA if none is available),
and returns a character vector. Warning: this likely discards valid values,
so make sure this is really what you want. If FALSE, returns a list of
the same length as input, with all values for each id stored in a list if
more than one is found.
- preferred
Logical, defaults to FALSE. If TRUE, returns properties
that have rank "preferred" if available; if no "preferred" property is
found, then it is ignored.
- latest_start_time
Logical, defaults to FALSE. If TRUE, returns the
property that has the most recent start time ("P580") as qualifier if
only_first is set to TRUE, or returns a list ordered by start time if
only_first is set to FALSE. If no such qualifier is found, then it is
ignored.
- language
Defaults to language set with tw_set_language(); if not
set, "en". Use "all_available" to keep all languages. For available
language values, see
the
dedicated Wikimedia page.
- id_df
Default to NULL. If given, it should be a dataframe typically
generated with tw_get(), and is used instead of calling Wikidata or
using SQLite cache. Ignored when id is of length more than one.
- cache
Defaults to NULL. If given, it should be given either TRUE
or FALSE. Typically set with tw_enable_cache() or tw_disable_cache().
- overwrite_cache
Logical, defaults to FALSE. If TRUE, it overwrites
the table in the local sqlite database. Useful if the original Wikidata
object has been updated.
- cache_connection
Defaults to NULL. If NULL, and caching is
enabled, tidywikidatar will use a local sqlite database. A custom
connection to other databases can be given (see vignette caching for
details).
- disconnect_db
Defaults to TRUE. If FALSE, leaves the connection to
cache open.
- wait
In seconds, defaults to 0. Time to wait between queries to
Wikidata. If data are cached locally, wait time is not applied. If you are
running many queries systematically you may want to add some waiting time
between queries.
- retry
Defaults to 10. Maximum number of times to retry if the API
throws an error, such as "too many requests". Each time, it will wait as
much time as requested by the API. Notice that this can be a long time,
e.g. 30 minutes. Set to FALSE if you prefer the API to throw an error
immediately. Consider adjusting the wait parameter, or customising the
user_agent if relevant.
- user_agent
Defaults to NULL. If not given, implicitly defaults to
current package name (tidywikidatar) and version.