View source: R/tw_get_property_with_details.R
| tw_get_property_with_details | R Documentation |
Gets all details of a property for one or more Wikidata items.
tw_get_property_with_details(id, p, wait = 0)
id |
A character vector, must start with Q, e.g. "Q180099" for the
anthropologist Margaret Mead. Can also be a data frame of one row,
typically generated with |
p |
A character vector, a property. Must always start with the capital letter "P", e.g. "P31" for "instance of". |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
A tibble, corresponding to the details for the given property. NULL
if no relevant property found.
# Get "female form of label", including language
tw_get_property_with_details(id = "Q64733534", p = "P2521")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.