Gets all details of a property
Source:R/tw_get_property_with_details.R
tw_get_property_with_details_single.RdUsed internally. Users should rely on tw_get_property_with_details().
Usage
tw_get_property_with_details_single(
id,
p,
retry = 10,
user_agent = tidywikidatar::tw_get_user_agent()
)Arguments
- id
A character vector, must start with Q, e.g. "Q180099" for the anthropologist Margaret Mead. Can also be a data frame of one row, typically generated with
tw_search()or a combination oftw_search()andtw_filter_first().- p
A character vector, a property. Must always start with the capital letter "P", e.g. "P31" for "instance of".
- retry
Defaults to 10. Maximum number of times to retry if the API throws an error, such as "too many requests". Each time, it will wait as much time as requested by the API. Notice that this can be a long time, e.g. 30 minutes. Set to
FALSEif you prefer the API to throw an error immediately. Consider adjusting thewaitparameter, or customising theuser_agentif relevant.- user_agent
Defaults to
NULL. If not given, implicitly defaults to current package name (tidywikidatar) and version.