View source: R/tw_get_property_with_details.R
| tw_get_property_with_details_single | R Documentation |
Used internally. Users should rely on tw_get_property_with_details().
tw_get_property_with_details_single(id, p)
id |
A character vector, must start with Q, e.g. "Q180099" for the
anthropologist Margaret Mead. Can also be a data frame of one row,
typically generated with |
p |
A character vector, a property. Must always start with the capital letter "P", e.g. "P31" for "instance of". |
A tibble, corresponding to the details for the given property. NULL
if no relevant property found.
# Get "female form of label", including language
tidywikidatar:::tw_get_property_with_details_single(id = "Q64733534", p = "P2521")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.