Learn R Programming

tidywikidatar (version 0.6.1)

tw_get_property_with_details_single: Gets all details of a property

Description

Used internally. Users should rely on tw_get_property_with_details().

Usage

tw_get_property_with_details_single(id, p)

Value

A tibble, corresponding to the details for the given property. NULL

if no relevant property found.

Arguments

id

A character vector, must start with Q, e.g. "Q180099" for the anthropologist Margaret Mead. Can also be a data frame of one row, typically generated with tw_search() or a combination of tw_search() and tw_filter_first().

p

A character vector, a property. Must always start with the capital letter "P", e.g. "P31" for "instance of".

Examples

Run this code
# Get "female form of label", including language
tidywikidatar:::tw_get_property_with_details_single(id = "Q64733534", p = "P2521")

Run the code above in your browser using DataLab