View source: R/tw_get_qualifiers.R
| tw_get_qualifiers | R Documentation |
N.B. In order to provide for consistently structured output, this function outputs either id or value for each qualifier. The user should keep in mind that some of these come with additional detail (e.g. the unit, precision, or reference calendar).
tw_get_qualifiers(
id,
p,
language = tidywikidatar::tw_get_language(),
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
wait = 0,
id_l = NULL
)
id |
A character vector, must start with Q, e.g. "Q180099" for the
anthropologist Margaret Mead. Can also be a data frame of one row,
typically generated with |
p |
A character vector, a property. Must always start with the capital letter "P", e.g. "P31" for "instance of". |
language |
Defaults to language set with |
cache |
Defaults to |
overwrite_cache |
Logical, defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
id_l |
Defaults to |
A data frame (a tibble) with eight columns: id for the input id,
property, qualifier_id, qualifier_property, qualifier_value,
rank, qualifier_value_type, and set (to distinguish sets of data when
a property is present more than once)
if (interactive()) {
tidywikidatar::tw_get_qualifiers(id = "Q180099", p = "P26", language = "en")
}
#' ## using `tw_test_items` in examples in order to show output without calling
## on Wikidata servers
tidywikidatar::tw_get_qualifiers(
id = "Q180099",
p = "P26",
language = "en",
id_l = tw_test_items
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.