Get URL to a Wikipedia article corresponding to a Wikidata Q identifier in given language
tw_get_wikipedia(
id,
full_link = TRUE,
language = tidywikidatar::tw_get_language(),
id_df = NULL,
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE,
wait = 0,
retry = 10,
user_agent = tidywikidatar::tw_get_user_agent()
)A character vector of the same length as the vector of id given, with the Wikipedia link in the requested language.
A character vector of length 1, must start with Q, e.g. "Q254" for Wolfgang Amadeus Mozart.
Logical, defaults to TRUE. If FALSE, returns only the
part of the url that corresponds to the title.
Defaults to language set with tw_set_language(); if not
set, "en". Use "all_available" to keep all languages. For available
language values, see
the
dedicated Wikimedia page.
Default to NULL. If given, it should be a dataframe typically
generated with tw_get(), and is used instead of calling Wikidata or
using SQLite cache. Ignored when id is of length more than one.
Defaults to NULL. If given, it should be given either TRUE
or FALSE. Typically set with tw_enable_cache() or tw_disable_cache().
Logical, defaults to FALSE. If TRUE, it overwrites
the table in the local sqlite database. Useful if the original Wikidata
object has been updated.
Defaults to NULL. If NULL, and caching is
enabled, tidywikidatar will use a local sqlite database. A custom
connection to other databases can be given (see vignette caching for
details).
Defaults to TRUE. If FALSE, leaves the connection to
cache open.
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries.
Defaults to 10. Maximum number of times to retry if the API
throws an error, such as "too many requests". Each time, it will wait as
much time as requested by the API. Notice that this can be a long time,
e.g. 30 minutes. Set to FALSE if you prefer the API to throw an error
immediately. Consider adjusting the wait parameter, or customising the
user_agent if relevant.
Defaults to NULL. If not given, implicitly defaults to
current package name (tidywikidatar) and version.
if (FALSE) {
tw_get_wikipedia(id = "Q180099")
}
Run the code above in your browser using DataLab