- url
A character vector with the full URL to one or more Wikipedia
pages. If given, title and language can be left empty.
- title
Title of a Wikipedia page or final parts of its url. If given,
url can be left empty, but language must be provided.
- language
Defaults to language set with tw_set_language(); if not
set, "en". Use "all_available" to keep all languages. For available
language values, see
the
dedicated Wikimedia page.
- cache
Defaults to NULL. If given, it should be given either TRUE
or FALSE. Typically set with tw_enable_cache() or tw_disable_cache().
- overwrite_cache
Logical, defaults to FALSE. If TRUE, it overwrites
the table in the local sqlite database. Useful if the original Wikidata
object has been updated.
- cache_connection
Defaults to NULL. If NULL, and caching is
enabled, tidywikidatar will use a local sqlite database. A custom
connection to other databases can be given (see vignette caching for
details).
- disconnect_db
Defaults to TRUE. If FALSE, leaves the connection to
cache open.
- wait
In seconds, defaults to 0. Time to wait between queries to
Wikidata. If data are cached locally, wait time is not applied. If you are
running many queries systematically you may want to add some waiting time
between queries.
- attempts
Defaults to 10. Number of times it re-attempts to reach the
API before failing.