Removes from cache the table where data typically gathered with
tw_get_wikipedia_category_members() are stored.
tw_reset_wikipedia_category_members_cache(
language = tidywikidatar::tw_get_language(),
type = "page",
cache = NULL,
cache_connection = NULL,
disconnect_db = TRUE,
ask = TRUE
)Nothing, used for its side effects.
Two-letter language code used to define the Wikipedia version
to use. Defaults to language set with tw_set_language(); if not set,
"en". If url given, this can be left empty.
Defaults to "page", defines which kind of members of a category
are returned. Valid values include "page", "file", and "subcat" (for
sub-category). Corresponds to cmtype. For details, see
the relevant page
of the official documentation.
Defaults to NULL. If given, it should be given either TRUE
or FALSE. Typically set with tw_enable_cache() or tw_disable_cache().
Defaults to NULL. If NULL, and caching is
enabled, tidywikidatar will use a local sqlite database. A custom
connection to other databases can be given (see vignette caching for
details).
Defaults to TRUE. If FALSE, leaves the connection to
cache open.
Logical, defaults to TRUE. If FALSE, and cache folder does not exist, it just creates it without asking (useful for non-interactive sessions).
if (interactive()) {
tw_reset_wikipedia_category_members_cache()
}
Run the code above in your browser using DataLab