| tw_search_item | R Documentation |
This search returns only items, use tw_search_property() for properties.
tw_search_item(
search,
language = tidywikidatar::tw_get_language(),
response_language = tidywikidatar::tw_get_language(),
limit = 10,
include_search = FALSE,
wait = 0,
user_agent = tidywikidatar::tw_get_user_agent(),
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE
)
search |
A string to be searched in Wikidata |
language |
Language to be used for the search. Can be set once per
session with |
response_language |
Language to be used for the returned labels and
descriptions. Corresponds to the |
limit |
Maximum numbers of responses to be given. |
include_search |
Logical, defaults to |
wait |
In seconds, defaults to 0. Time to wait between queries to Wikidata. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries. |
user_agent |
Defaults to |
cache |
Defaults to |
overwrite_cache |
Defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
A data frame (a tibble) with three columns (id, label, and
description), and as many rows as there are results (by default, limited
to 10).
tw_search_item(search = "Sylvia Pankhurst")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.