View source: R/tw_get_qualifiers.R
| tw_write_qualifiers_to_cache | R Documentation |
Mostly to be used internally by tidywikidatar, use with caution to keep
caching consistent.
tw_write_qualifiers_to_cache(
qualifiers_df,
language = tidywikidatar::tw_get_language(),
cache = NULL,
overwrite_cache = FALSE,
cache_connection = NULL,
disconnect_db = TRUE
)
qualifiers_df |
A data frame typically generated with
|
language |
Defaults to language set with |
cache |
Defaults to |
overwrite_cache |
Logical, defaults to |
cache_connection |
Defaults to |
disconnect_db |
Defaults to |
Silently returns the same data frame provided as input. Mostly used internally for its side effects.
q_df <- tw_get_qualifiers(
id = "Q180099",
p = "P26",
language = "en",
cache = FALSE
)
tw_write_qualifiers_to_cache(
qualifiers_df = q_df,
language = "en",
cache = TRUE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.